v0.3.3 (February 16, 2022)
==========================
  * Fix attribute errors in bagging and cross-validation. Loosen dependency reqs (#108)
  * Make AFQDataset work with different input formats and make indexable (#105)

